# == Schema Information
#
# Table name: learning_objects
#
#  id                     :integer          not null, primary key
#  id_dspace              :integer
#  name                   :string
#  author                 :string
#  description            :text
#  published_at           :datetime
#  score                  :float            default("0.0")
#  school_level           :integer
#  metadata               :jsonb            default("{}")
#  keywords               :text
#  publisher_id           :integer
#  publisher_type         :string
#  language_id            :integer
#  object_type_id         :integer
#  created_at             :datetime         not null
#  updated_at             :datetime         not null
#  views_count            :integer          default("0")
#  downloads_count        :integer          default("0")
#  likes_count            :integer          default("0")
#  shares_count           :integer          default("0")
#  state                  :string           default("published")
#  thumbnail_file_name    :string
#  thumbnail_content_type :string
#  thumbnail_file_size    :integer
#  thumbnail_updated_at   :datetime
#  attachment_id          :integer
#

require 'test_helper'

class LearningObjectTest < ActiveSupport::TestCase
  should have_and_belong_to_many :topics

  should have_many :collection_items
  should have_many(:collections).through(:collection_items)
  should have_many :complaints
  should have_many(:attachments).class_name('LearningObject::Attachment')

  should belong_to :publisher
  should belong_to :language
  should belong_to(:attachment).class_name('LearningObject::Attachment')
  should belong_to :object_type

  #sociable
  should have_many :views
  should have_many :downloads
  should have_many :likes
  should have_many :shares
  include ::Portalmec::SociableTests

  protected

  def sociable_object
    learning_objects(:user_lo)
  end

  def sociable_user
    users(:john)
  end
end
